==> groupsms_0.1.0.tar.gz: groupsms-0.1.0/contactsloader.cpp <==
//    GroupSMS
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#include "contactsloader.h"
#include <QFile>
#include <QSettings>
#include "contact.h"
#include "commonstatic.h"


bool toAscending(const Contact* s1 , const Contact* s2)
{
    return s1->Name < s2->Name;
}

void ContactsLoader::run()
{    
#ifdef Q_OS_SYMBIAN
    setStackSize(163840);
#endif
    CommonStatic::ContactsCache.clear();
    QStringList* numbers = new QStringList();

#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
    //Symbian and Maemo implementation (read phonebook from phone)
    //Collect contacts from all managers:
    QContactManager* man = NULL;
    QStringList availableManagers = QContactManager::availableManagers();
    QList<QContact> contacts;
    while (!availableManagers.isEmpty()) {
        man = new QContactManager(availableManagers.takeFirst());

#ifdef Q_WS_MAEMO_5
        QList<QContact> tContacts = man->contacts();
        if (!tContacts.isEmpty()){
            contacts.append(tContacts);
            tContacts.clear();
        }
#endif

        delete man;
        man = NULL;
    }

    numbers->clear();
    if (!contacts.isEmpty()){
        foreach (QContact c, contacts){
            msleep(5);
            QStringList cNumbers;
            if (IsContactValid(&c, &cNumbers)) {
                foreach (QString number, cNumbers){
                    if (!numbers->contains(number)){
                        numbers->append(number);
                        Contact* contact = new Contact();
                        contact->Id = c.localId();
                        contact->Name = c.displayLabel();
                        contact->Number = number;

                        QContactThumbnail thn = c.detail(QContactThumbnail::DefinitionName);
                        if (!thn.isEmpty())
                            contact->Thumbnail = new QImage(thn.thumbnail().scaled(48, 48, Qt::KeepAspectRatio));
                        CommonStatic::ContactsCache.append(contact);
                    }
                }
            }
        }
    }

#else
    // Windows implementation (read a phonebook from file)
    QString book = QString("%1/contacts.conf").arg(CommonStatic::GetSettingsFolder());
    if (!QFile::exists(book))
        return;

    QSettings* contacts = new QSettings(book, QSettings::IniFormat);

    contacts->beginGroup("Contacts");

    int max = contacts->beginReadArray("items");
    for (int i = 0; i < max; ++i) {
        msleep(10);
        contacts->setArrayIndex(i);

        Contact* contact = new Contact();
        contact->Id = contacts->value("id").toInt();
        contact->Name = contacts->value("name").toString();
        contact->Number = contacts->value("number").toString();

        CommonStatic::ContactsCache.append(contact);
    }

    contacts->endArray();
    contacts->endGroup();
    delete contacts;
#endif

    delete numbers;
    qSort(CommonStatic::ContactsCache.begin() , CommonStatic::ContactsCache.end(), toAscending );
}

#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
bool ContactsLoader::IsContactValid(QContact* c, QStringList* numbers)
{
    numbers->clear();
    if (!c->isEmpty() && c->type() == QContactType::TypeContact){
        QList<QContactDetail> phns = c->details(QContactPhoneNumber::DefinitionName);
        foreach (QContactDetail detail, phns){
            QContactPhoneNumber* phn = (QContactPhoneNumber*)(&detail);
            QString tNumber = phn->number();
            numbers->append(tNumber);
        }
        return true;
    }
    return false;
}
#endif

==> groupsms_0.1.7.tar.gz: groupsms-0.1.7/contactsloader.cpp <==
//    GroupSMS
//    Copyright (C) 2011 Paolo Iommarini
//    sakya_tg@yahoo.it
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#include "contactsloader.h"
#include <QFile>
#include <QSettings>
#include "contact.h"
#include "commonstatic.h"


bool toAscending(const Contact* s1 , const Contact* s2)
{
    return s1->Name < s2->Name;
}

void ContactsLoader::run()
{    
#ifdef Q_OS_SYMBIAN
    setStackSize(163840);
#endif
    CommonStatic::ContactsCache.clear();
    CommonStatic::ContactsCacheNumbers.clear();
    CommonStatic::ContactsCacheIds.clear();
    QStringList* numbers = new QStringList();

#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
    //Symbian and Maemo implementation (read phonebook from phone)
    //Collect contacts from all managers:
    QContactManager* man = NULL;
    QStringList availableManagers = QContactManager::availableManagers();
    QList<QContact> contacts;
    while (!availableManagers.isEmpty()) {
        man = new QContactManager(availableManagers.takeFirst());

#ifdef Q_WS_MAEMO_5
        QList<QContact> tContacts = man->contacts();
        if (!tContacts.isEmpty()){
            contacts.append(tContacts);
            tContacts.clear();
        }
#endif

        delete man;
        man = NULL;
    }

    numbers->clear();
    if (!contacts.isEmpty()){
        foreach (QContact c, contacts){
            QStringList cNumbers;
            if (IsContactValid(&c, &cNumbers)) {
                foreach (QString number, cNumbers){
                    if (!numbers->contains(number)){
                        numbers->append(number);
                        Contact* contact = new Contact();
                        contact->Id = c.localId();
                        contact->Name = c.displayLabel();
                        contact->Number = number;

                        QContactThumbnail thn = c.detail(QContactThumbnail::DefinitionName);
                        if (!thn.isEmpty())
                            contact->Thumbnail = new QImage(thn.thumbnail().scaled(48, 48, Qt::KeepAspectRatio));
                        CommonStatic::ContactsCache.append(contact);
                        CommonStatic::ContactsCacheNumbers[contact->Number] = contact->Id;
                        CommonStatic::ContactsCacheIds[contact->Id] = contact;
                    }
                }
            }
        }
    }

#else
    // Windows implementation (read a phonebook from file)
    QString book = QString("%1/contacts.conf").arg(CommonStatic::GetSettingsFolder());
    if (!QFile::exists(book))
        return;

    QSettings* contacts = new QSettings(book, QSettings::IniFormat);

    contacts->beginGroup("Contacts");

    int max = contacts->beginReadArray("items");
    for (int i = 0; i < max; ++i) {
        contacts->setArrayIndex(i);

        Contact* contact = new Contact();
        contact->Id = contacts->value("id").toInt();
        contact->Name = contacts->value("name").toString();
        contact->Number = contacts->value("number").toString();

        CommonStatic::ContactsCache.append(contact);
        CommonStatic::ContactsCacheNumbers[contact->Number] = contact->Id;
        CommonStatic::ContactsCacheIds[contact->Id] = contact;
    }

    contacts->endArray();
    contacts->endGroup();
    delete contacts;
#endif

    delete numbers;
    qSort(CommonStatic::ContactsCache.begin() , CommonStatic::ContactsCache.end(), toAscending );
}

#if defined(Q_OS_SYMBIAN) || defined(Q_WS_MAEMO_5)
bool ContactsLoader::IsContactValid(QContact* c, QStringList* numbers)
{
    numbers->clear();
    if (!c->isEmpty() && c->type() == QContactType::TypeContact){
        QList<QContactDetail> phns = c->details(QContactPhoneNumber::DefinitionName);
        foreach (QContactDetail detail, phns){
            QContactPhoneNumber* phn = (QContactPhoneNumber*)(&detail);
            numbers->append(phn->number());
        }
        return true;
    }
    return false;
}
#endif
